==> arquillian-parent-1.1.13.Final-source-release.zip: arquillian-parent-1.1.13.Final/test/spi/src/main/java/org/jboss/arquillian/test/spi/event/suite/Test.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.test.spi.event.suite;

import org.jboss.arquillian.test.spi.TestMethodExecutor;

/**
 * Event fired to execute the Test method
 *
 * @author <a href="mailto:aslak@conduct.no">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class Test extends TestEvent
{
   private TestMethodExecutor testMethodExecutor;
   
   /**
    * @param testMethodExecutor The executor responsible for executing the test method
    */
   public Test(TestMethodExecutor testMethodExecutor)
   {
      // TODO: how to validate testMethodExecutor
      super(testMethodExecutor.getInstance(), testMethodExecutor.getMethod());
      
      //Validate.notNull(testMethodExecutor, "TestMethodExecutor must be specified");
      
      this.testMethodExecutor = testMethodExecutor;
   }
   
   public TestMethodExecutor getTestMethodExecutor()
   {
      return testMethodExecutor;
   }
}

==> arquillian-parent-1.9.4.Final-source-release.zip: arquillian-parent-1.9.4.Final/test/spi/src/main/java/org/jboss/arquillian/test/spi/event/suite/Test.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.test.spi.event.suite;

import org.jboss.arquillian.test.spi.TestMethodExecutor;

/**
 * Event fired to execute the Test method
 *
 * @author <a href="mailto:aslak@conduct.no">Aslak Knutsen</a>
 */
public class Test extends TestEvent {
    private TestMethodExecutor testMethodExecutor;

    /**
     * @param testMethodExecutor
     *     The executor responsible for executing the test method
     */
    public Test(TestMethodExecutor testMethodExecutor) {
        // TODO: how to validate testMethodExecutor
        super(testMethodExecutor.getInstance(), testMethodExecutor.getMethod());

        //Validate.notNull(testMethodExecutor, "TestMethodExecutor must be specified");

        this.testMethodExecutor = testMethodExecutor;
    }

    public TestMethodExecutor getTestMethodExecutor() {
        return testMethodExecutor;
    }
}
